# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.papers import version_request_ai_overview_params
from ...types.papers.version_request_ai_overview_response import VersionRequestAIOverviewResponse
from ...types.papers.version_request_ai_translation_response import VersionRequestAITranslationResponse

__all__ = ["VersionsResource", "AsyncVersionsResource"]


class VersionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return VersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return VersionsResourceWithStreamingResponse(self)

    def request_ai_overview(
        self,
        version_order: str,
        *,
        upid: str,
        preferred_language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionRequestAIOverviewResponse:
        """
        Request AI overview generation for a paper version

        Source file: `api-server/src/controllers/v2/papers/request-ai.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_order:
            raise ValueError(f"Expected a non-empty value for `version_order` but received {version_order!r}")
        return self._post(
            f"/v2/papers/{upid}/versions/{version_order}/request-ai",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"preferred_language": preferred_language},
                    version_request_ai_overview_params.VersionRequestAIOverviewParams,
                ),
            ),
            cast_to=VersionRequestAIOverviewResponse,
        )

    def request_ai_translation(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        upid: str,
        version_order: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionRequestAITranslationResponse:
        """
        Request AI overview translation for a paper version

        Source file:
        `api-server/src/controllers/v2/papers/request-ai-translation.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_order:
            raise ValueError(f"Expected a non-empty value for `version_order` but received {version_order!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return self._post(
            f"/v2/papers/{upid}/versions/{version_order}/request-ai-translation/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionRequestAITranslationResponse,
        )


class AsyncVersionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncVersionsResourceWithStreamingResponse(self)

    async def request_ai_overview(
        self,
        version_order: str,
        *,
        upid: str,
        preferred_language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionRequestAIOverviewResponse:
        """
        Request AI overview generation for a paper version

        Source file: `api-server/src/controllers/v2/papers/request-ai.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_order:
            raise ValueError(f"Expected a non-empty value for `version_order` but received {version_order!r}")
        return await self._post(
            f"/v2/papers/{upid}/versions/{version_order}/request-ai",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"preferred_language": preferred_language},
                    version_request_ai_overview_params.VersionRequestAIOverviewParams,
                ),
            ),
            cast_to=VersionRequestAIOverviewResponse,
        )

    async def request_ai_translation(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        upid: str,
        version_order: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionRequestAITranslationResponse:
        """
        Request AI overview translation for a paper version

        Source file:
        `api-server/src/controllers/v2/papers/request-ai-translation.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_order:
            raise ValueError(f"Expected a non-empty value for `version_order` but received {version_order!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return await self._post(
            f"/v2/papers/{upid}/versions/{version_order}/request-ai-translation/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionRequestAITranslationResponse,
        )


class VersionsResourceWithRawResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.request_ai_overview = to_raw_response_wrapper(
            versions.request_ai_overview,
        )
        self.request_ai_translation = to_raw_response_wrapper(
            versions.request_ai_translation,
        )


class AsyncVersionsResourceWithRawResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.request_ai_overview = async_to_raw_response_wrapper(
            versions.request_ai_overview,
        )
        self.request_ai_translation = async_to_raw_response_wrapper(
            versions.request_ai_translation,
        )


class VersionsResourceWithStreamingResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.request_ai_overview = to_streamed_response_wrapper(
            versions.request_ai_overview,
        )
        self.request_ai_translation = to_streamed_response_wrapper(
            versions.request_ai_translation,
        )


class AsyncVersionsResourceWithStreamingResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.request_ai_overview = async_to_streamed_response_wrapper(
            versions.request_ai_overview,
        )
        self.request_ai_translation = async_to_streamed_response_wrapper(
            versions.request_ai_translation,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .mcp import (
    McpResource,
    AsyncMcpResource,
    McpResourceWithRawResponse,
    AsyncMcpResourceWithRawResponse,
    McpResourceWithStreamingResponse,
    AsyncMcpResourceWithStreamingResponse,
)
from .admin import (
    AdminResource,
    AsyncAdminResource,
    AdminResourceWithRawResponse,
    AsyncAdminResourceWithRawResponse,
    AdminResourceWithStreamingResponse,
    AsyncAdminResourceWithStreamingResponse,
)
from .arxiv import (
    ArxivResource,
    AsyncArxivResource,
    ArxivResourceWithRawResponse,
    AsyncArxivResourceWithRawResponse,
    ArxivResourceWithStreamingResponse,
    AsyncArxivResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .briefs import (
    BriefsResource,
    AsyncBriefsResource,
    BriefsResourceWithRawResponse,
    AsyncBriefsResourceWithRawResponse,
    BriefsResourceWithStreamingResponse,
    AsyncBriefsResourceWithStreamingResponse,
)
from .emails import (
    EmailsResource,
    AsyncEmailsResource,
    EmailsResourceWithRawResponse,
    AsyncEmailsResourceWithRawResponse,
    EmailsResourceWithStreamingResponse,
    AsyncEmailsResourceWithStreamingResponse,
)
from .events import (
    EventsResource,
    AsyncEventsResource,
    EventsResourceWithRawResponse,
    AsyncEventsResourceWithRawResponse,
    EventsResourceWithStreamingResponse,
    AsyncEventsResourceWithStreamingResponse,
)
from .papers import (
    PapersResource,
    AsyncPapersResource,
    PapersResourceWithRawResponse,
    AsyncPapersResourceWithRawResponse,
    PapersResourceWithStreamingResponse,
    AsyncPapersResourceWithStreamingResponse,
)
from .retool import (
    RetoolResource,
    AsyncRetoolResource,
    RetoolResourceWithRawResponse,
    AsyncRetoolResourceWithRawResponse,
    RetoolResourceWithStreamingResponse,
    AsyncRetoolResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .folders import (
    FoldersResource,
    AsyncFoldersResource,
    FoldersResourceWithRawResponse,
    AsyncFoldersResourceWithRawResponse,
    FoldersResourceWithStreamingResponse,
    AsyncFoldersResourceWithStreamingResponse,
)
from .wrapped import (
    WrappedResource,
    AsyncWrappedResource,
    WrappedResourceWithRawResponse,
    AsyncWrappedResourceWithRawResponse,
    WrappedResourceWithStreamingResponse,
    AsyncWrappedResourceWithStreamingResponse,
)
from .api_keys import (
    APIKeysResource,
    AsyncAPIKeysResource,
    APIKeysResourceWithRawResponse,
    AsyncAPIKeysResourceWithRawResponse,
    APIKeysResourceWithStreamingResponse,
    AsyncAPIKeysResourceWithStreamingResponse,
)
from .comments import (
    CommentsResource,
    AsyncCommentsResource,
    CommentsResourceWithRawResponse,
    AsyncCommentsResourceWithRawResponse,
    CommentsResourceWithStreamingResponse,
    AsyncCommentsResourceWithStreamingResponse,
)
from .research import (
    ResearchResource,
    AsyncResearchResource,
    ResearchResourceWithRawResponse,
    AsyncResearchResourceWithRawResponse,
    ResearchResourceWithStreamingResponse,
    AsyncResearchResourceWithStreamingResponse,
)
from .retrieve import (
    RetrieveResource,
    AsyncRetrieveResource,
    RetrieveResourceWithRawResponse,
    AsyncRetrieveResourceWithRawResponse,
    RetrieveResourceWithStreamingResponse,
    AsyncRetrieveResourceWithStreamingResponse,
)
from .sitemaps import (
    SitemapsResource,
    AsyncSitemapsResource,
    SitemapsResourceWithRawResponse,
    AsyncSitemapsResourceWithRawResponse,
    SitemapsResourceWithStreamingResponse,
    AsyncSitemapsResourceWithStreamingResponse,
)
from .analytics import (
    AnalyticsResource,
    AsyncAnalyticsResource,
    AnalyticsResourceWithRawResponse,
    AsyncAnalyticsResourceWithRawResponse,
    AnalyticsResourceWithStreamingResponse,
    AsyncAnalyticsResourceWithStreamingResponse,
)
from .assistant import (
    AssistantResource,
    AsyncAssistantResource,
    AssistantResourceWithRawResponse,
    AsyncAssistantResourceWithRawResponse,
    AssistantResourceWithStreamingResponse,
    AsyncAssistantResourceWithStreamingResponse,
)
from .well_known import (
    WellKnownResource,
    AsyncWellKnownResource,
    WellKnownResourceWithRawResponse,
    AsyncWellKnownResourceWithRawResponse,
    WellKnownResourceWithStreamingResponse,
    AsyncWellKnownResourceWithStreamingResponse,
)
from .notifications import (
    NotificationsResource,
    AsyncNotificationsResource,
    NotificationsResourceWithRawResponse,
    AsyncNotificationsResourceWithRawResponse,
    NotificationsResourceWithStreamingResponse,
    AsyncNotificationsResourceWithStreamingResponse,
)
from .organizations import (
    OrganizationsResource,
    AsyncOrganizationsResource,
    OrganizationsResourceWithRawResponse,
    AsyncOrganizationsResourceWithRawResponse,
    OrganizationsResourceWithStreamingResponse,
    AsyncOrganizationsResourceWithStreamingResponse,
)
from .google_scholar import (
    GoogleScholarResource,
    AsyncGoogleScholarResource,
    GoogleScholarResourceWithRawResponse,
    AsyncGoogleScholarResourceWithRawResponse,
    GoogleScholarResourceWithStreamingResponse,
    AsyncGoogleScholarResourceWithStreamingResponse,
)

__all__ = [
    "PapersResource",
    "AsyncPapersResource",
    "PapersResourceWithRawResponse",
    "AsyncPapersResourceWithRawResponse",
    "PapersResourceWithStreamingResponse",
    "AsyncPapersResourceWithStreamingResponse",
    "EmailsResource",
    "AsyncEmailsResource",
    "EmailsResourceWithRawResponse",
    "AsyncEmailsResourceWithRawResponse",
    "EmailsResourceWithStreamingResponse",
    "AsyncEmailsResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
    "AssistantResource",
    "AsyncAssistantResource",
    "AssistantResourceWithRawResponse",
    "AsyncAssistantResourceWithRawResponse",
    "AssistantResourceWithStreamingResponse",
    "AsyncAssistantResourceWithStreamingResponse",
    "FoldersResource",
    "AsyncFoldersResource",
    "FoldersResourceWithRawResponse",
    "AsyncFoldersResourceWithRawResponse",
    "FoldersResourceWithStreamingResponse",
    "AsyncFoldersResourceWithStreamingResponse",
    "CommentsResource",
    "AsyncCommentsResource",
    "CommentsResourceWithRawResponse",
    "AsyncCommentsResourceWithRawResponse",
    "CommentsResourceWithStreamingResponse",
    "AsyncCommentsResourceWithStreamingResponse",
    "AnalyticsResource",
    "AsyncAnalyticsResource",
    "AnalyticsResourceWithRawResponse",
    "AsyncAnalyticsResourceWithRawResponse",
    "AnalyticsResourceWithStreamingResponse",
    "AsyncAnalyticsResourceWithStreamingResponse",
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "OrganizationsResource",
    "AsyncOrganizationsResource",
    "OrganizationsResourceWithRawResponse",
    "AsyncOrganizationsResourceWithRawResponse",
    "OrganizationsResourceWithStreamingResponse",
    "AsyncOrganizationsResourceWithStreamingResponse",
    "GoogleScholarResource",
    "AsyncGoogleScholarResource",
    "GoogleScholarResourceWithRawResponse",
    "AsyncGoogleScholarResourceWithRawResponse",
    "GoogleScholarResourceWithStreamingResponse",
    "AsyncGoogleScholarResourceWithStreamingResponse",
    "ArxivResource",
    "AsyncArxivResource",
    "ArxivResourceWithRawResponse",
    "AsyncArxivResourceWithRawResponse",
    "ArxivResourceWithStreamingResponse",
    "AsyncArxivResourceWithStreamingResponse",
    "APIKeysResource",
    "AsyncAPIKeysResource",
    "APIKeysResourceWithRawResponse",
    "AsyncAPIKeysResourceWithRawResponse",
    "APIKeysResourceWithStreamingResponse",
    "AsyncAPIKeysResourceWithStreamingResponse",
    "AdminResource",
    "AsyncAdminResource",
    "AdminResourceWithRawResponse",
    "AsyncAdminResourceWithRawResponse",
    "AdminResourceWithStreamingResponse",
    "AsyncAdminResourceWithStreamingResponse",
    "WrappedResource",
    "AsyncWrappedResource",
    "WrappedResourceWithRawResponse",
    "AsyncWrappedResourceWithRawResponse",
    "WrappedResourceWithStreamingResponse",
    "AsyncWrappedResourceWithStreamingResponse",
    "NotificationsResource",
    "AsyncNotificationsResource",
    "NotificationsResourceWithRawResponse",
    "AsyncNotificationsResourceWithRawResponse",
    "NotificationsResourceWithStreamingResponse",
    "AsyncNotificationsResourceWithStreamingResponse",
    "SitemapsResource",
    "AsyncSitemapsResource",
    "SitemapsResourceWithRawResponse",
    "AsyncSitemapsResourceWithRawResponse",
    "SitemapsResourceWithStreamingResponse",
    "AsyncSitemapsResourceWithStreamingResponse",
    "RetrieveResource",
    "AsyncRetrieveResource",
    "RetrieveResourceWithRawResponse",
    "AsyncRetrieveResourceWithRawResponse",
    "RetrieveResourceWithStreamingResponse",
    "AsyncRetrieveResourceWithStreamingResponse",
    "RetoolResource",
    "AsyncRetoolResource",
    "RetoolResourceWithRawResponse",
    "AsyncRetoolResourceWithRawResponse",
    "RetoolResourceWithStreamingResponse",
    "AsyncRetoolResourceWithStreamingResponse",
    "BriefsResource",
    "AsyncBriefsResource",
    "BriefsResourceWithRawResponse",
    "AsyncBriefsResourceWithRawResponse",
    "BriefsResourceWithStreamingResponse",
    "AsyncBriefsResourceWithStreamingResponse",
    "ResearchResource",
    "AsyncResearchResource",
    "ResearchResourceWithRawResponse",
    "AsyncResearchResourceWithRawResponse",
    "ResearchResourceWithStreamingResponse",
    "AsyncResearchResourceWithStreamingResponse",
    "McpResource",
    "AsyncMcpResource",
    "McpResourceWithRawResponse",
    "AsyncMcpResourceWithRawResponse",
    "McpResourceWithStreamingResponse",
    "AsyncMcpResourceWithStreamingResponse",
    "EventsResource",
    "AsyncEventsResource",
    "EventsResourceWithRawResponse",
    "AsyncEventsResourceWithRawResponse",
    "EventsResourceWithStreamingResponse",
    "AsyncEventsResourceWithStreamingResponse",
    "WellKnownResource",
    "AsyncWellKnownResource",
    "WellKnownResourceWithRawResponse",
    "AsyncWellKnownResourceWithRawResponse",
    "WellKnownResourceWithStreamingResponse",
    "AsyncWellKnownResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import sitemap_list_users_params, sitemap_list_papers_params, sitemap_list_overviews_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.sitemap_list_users_response import SitemapListUsersResponse
from ..types.sitemap_list_papers_response import SitemapListPapersResponse
from ..types.sitemap_list_overviews_response import SitemapListOverviewsResponse

__all__ = ["SitemapsResource", "AsyncSitemapsResource"]


class SitemapsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SitemapsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return SitemapsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SitemapsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return SitemapsResourceWithStreamingResponse(self)

    def list_overviews(
        self,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SitemapListOverviewsResponse:
        """
        Get paginated list of paper versions with AI overviews for sitemap generation

        Source file:
        `api-server/src/controllers/v1/sitemaps/get-overviews-for-sitemap.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/sitemaps/overviews",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    sitemap_list_overviews_params.SitemapListOverviewsParams,
                ),
            ),
            cast_to=SitemapListOverviewsResponse,
        )

    def list_papers(
        self,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SitemapListPapersResponse:
        """Get paginated list of public papers for sitemap generation.

        Uses cursor caching
        for efficient deep pagination.

        Source file:
        `api-server/src/controllers/v1/sitemaps/get-papers-for-sitemap.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/sitemaps/papers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    sitemap_list_papers_params.SitemapListPapersParams,
                ),
            ),
            cast_to=SitemapListPapersResponse,
        )

    def list_users(
        self,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SitemapListUsersResponse:
        """
        Get paginated list of users for sitemap generation

        Source file:
        `api-server/src/controllers/v1/sitemaps/get-users-for-sitemap.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/sitemaps/users",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    sitemap_list_users_params.SitemapListUsersParams,
                ),
            ),
            cast_to=SitemapListUsersResponse,
        )


class AsyncSitemapsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSitemapsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSitemapsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSitemapsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncSitemapsResourceWithStreamingResponse(self)

    async def list_overviews(
        self,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SitemapListOverviewsResponse:
        """
        Get paginated list of paper versions with AI overviews for sitemap generation

        Source file:
        `api-server/src/controllers/v1/sitemaps/get-overviews-for-sitemap.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/sitemaps/overviews",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    sitemap_list_overviews_params.SitemapListOverviewsParams,
                ),
            ),
            cast_to=SitemapListOverviewsResponse,
        )

    async def list_papers(
        self,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SitemapListPapersResponse:
        """Get paginated list of public papers for sitemap generation.

        Uses cursor caching
        for efficient deep pagination.

        Source file:
        `api-server/src/controllers/v1/sitemaps/get-papers-for-sitemap.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/sitemaps/papers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    sitemap_list_papers_params.SitemapListPapersParams,
                ),
            ),
            cast_to=SitemapListPapersResponse,
        )

    async def list_users(
        self,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SitemapListUsersResponse:
        """
        Get paginated list of users for sitemap generation

        Source file:
        `api-server/src/controllers/v1/sitemaps/get-users-for-sitemap.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/sitemaps/users",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    sitemap_list_users_params.SitemapListUsersParams,
                ),
            ),
            cast_to=SitemapListUsersResponse,
        )


class SitemapsResourceWithRawResponse:
    def __init__(self, sitemaps: SitemapsResource) -> None:
        self._sitemaps = sitemaps

        self.list_overviews = to_raw_response_wrapper(
            sitemaps.list_overviews,
        )
        self.list_papers = to_raw_response_wrapper(
            sitemaps.list_papers,
        )
        self.list_users = to_raw_response_wrapper(
            sitemaps.list_users,
        )


class AsyncSitemapsResourceWithRawResponse:
    def __init__(self, sitemaps: AsyncSitemapsResource) -> None:
        self._sitemaps = sitemaps

        self.list_overviews = async_to_raw_response_wrapper(
            sitemaps.list_overviews,
        )
        self.list_papers = async_to_raw_response_wrapper(
            sitemaps.list_papers,
        )
        self.list_users = async_to_raw_response_wrapper(
            sitemaps.list_users,
        )


class SitemapsResourceWithStreamingResponse:
    def __init__(self, sitemaps: SitemapsResource) -> None:
        self._sitemaps = sitemaps

        self.list_overviews = to_streamed_response_wrapper(
            sitemaps.list_overviews,
        )
        self.list_papers = to_streamed_response_wrapper(
            sitemaps.list_papers,
        )
        self.list_users = to_streamed_response_wrapper(
            sitemaps.list_users,
        )


class AsyncSitemapsResourceWithStreamingResponse:
    def __init__(self, sitemaps: AsyncSitemapsResource) -> None:
        self._sitemaps = sitemaps

        self.list_overviews = async_to_streamed_response_wrapper(
            sitemaps.list_overviews,
        )
        self.list_papers = async_to_streamed_response_wrapper(
            sitemaps.list_papers,
        )
        self.list_users = async_to_streamed_response_wrapper(
            sitemaps.list_users,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

__all__ = ["V4ListNotificationsResponse"]

V4ListNotificationsResponse: TypeAlias = List[Optional[object]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .moderator_toggle_flags_params import ModeratorToggleFlagsParams as ModeratorToggleFlagsParams
from .moderator_send_feedback_params import ModeratorSendFeedbackParams as ModeratorSendFeedbackParams
from .moderator_toggle_flags_response import ModeratorToggleFlagsResponse as ModeratorToggleFlagsResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers import PrivateCreateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPrivate:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: AlphaxivCat) -> None:
        private = client.papers.private.create(
            content_type="x",
            file="x",
            filename="x",
        )
        assert_matches_type(PrivateCreateResponse, private, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: AlphaxivCat) -> None:
        response = client.papers.private.with_raw_response.create(
            content_type="x",
            file="x",
            filename="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = response.parse()
        assert_matches_type(PrivateCreateResponse, private, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: AlphaxivCat) -> None:
        with client.papers.private.with_streaming_response.create(
            content_type="x",
            file="x",
            filename="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = response.parse()
            assert_matches_type(PrivateCreateResponse, private, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_metadata(self, client: AlphaxivCat) -> None:
        private = client.papers.private.update_metadata(
            paper_id="paperId",
            abstract="abstract",
            authors=[{"name": "x"}],
            bibtex="bibtex",
            categories=["string"],
            publication_date=0,
            title="x",
        )
        assert private is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_metadata(self, client: AlphaxivCat) -> None:
        response = client.papers.private.with_raw_response.update_metadata(
            paper_id="paperId",
            abstract="abstract",
            authors=[{"name": "x"}],
            bibtex="bibtex",
            categories=["string"],
            publication_date=0,
            title="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = response.parse()
        assert private is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_metadata(self, client: AlphaxivCat) -> None:
        with client.papers.private.with_streaming_response.update_metadata(
            paper_id="paperId",
            abstract="abstract",
            authors=[{"name": "x"}],
            bibtex="bibtex",
            categories=["string"],
            publication_date=0,
            title="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = response.parse()
            assert private is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_metadata(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.private.with_raw_response.update_metadata(
                paper_id="",
                abstract="abstract",
                authors=[{"name": "x"}],
                bibtex="bibtex",
                categories=["string"],
                publication_date=0,
                title="x",
            )


class TestAsyncPrivate:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAlphaxivCat) -> None:
        private = await async_client.papers.private.create(
            content_type="x",
            file="x",
            filename="x",
        )
        assert_matches_type(PrivateCreateResponse, private, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.private.with_raw_response.create(
            content_type="x",
            file="x",
            filename="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = await response.parse()
        assert_matches_type(PrivateCreateResponse, private, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.private.with_streaming_response.create(
            content_type="x",
            file="x",
            filename="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = await response.parse()
            assert_matches_type(PrivateCreateResponse, private, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        private = await async_client.papers.private.update_metadata(
            paper_id="paperId",
            abstract="abstract",
            authors=[{"name": "x"}],
            bibtex="bibtex",
            categories=["string"],
            publication_date=0,
            title="x",
        )
        assert private is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.private.with_raw_response.update_metadata(
            paper_id="paperId",
            abstract="abstract",
            authors=[{"name": "x"}],
            bibtex="bibtex",
            categories=["string"],
            publication_date=0,
            title="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        private = await response.parse()
        assert private is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.private.with_streaming_response.update_metadata(
            paper_id="paperId",
            abstract="abstract",
            authors=[{"name": "x"}],
            bibtex="bibtex",
            categories=["string"],
            publication_date=0,
            title="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            private = await response.parse()
            assert private is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.private.with_raw_response.update_metadata(
                paper_id="",
                abstract="abstract",
                authors=[{"name": "x"}],
                bibtex="bibtex",
                categories=["string"],
                publication_date=0,
                title="x",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.briefs.v1 import seen_mark_seen_params
from ....types.briefs.v1.seen_get_seen_response import SeenGetSeenResponse

__all__ = ["SeenResource", "AsyncSeenResource"]


class SeenResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SeenResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return SeenResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SeenResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return SeenResourceWithStreamingResponse(self)

    def get_seen(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SeenGetSeenResponse:
        """
        Returns the list of paper group IDs the current user has already viewed as
        briefs

        Source file: `api-server/src/controllers/briefs/v1/get-seen.controller.ts`
        """
        return self._get(
            "/briefs/v1/seen",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SeenGetSeenResponse,
        )

    def mark_seen(
        self,
        *,
        paper_group_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Records that the current user has viewed a brief for the given paper group

        Source file: `api-server/src/controllers/briefs/v1/mark-seen.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/briefs/v1/seen",
            body=maybe_transform({"paper_group_id": paper_group_id}, seen_mark_seen_params.SeenMarkSeenParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncSeenResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSeenResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSeenResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSeenResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncSeenResourceWithStreamingResponse(self)

    async def get_seen(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SeenGetSeenResponse:
        """
        Returns the list of paper group IDs the current user has already viewed as
        briefs

        Source file: `api-server/src/controllers/briefs/v1/get-seen.controller.ts`
        """
        return await self._get(
            "/briefs/v1/seen",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SeenGetSeenResponse,
        )

    async def mark_seen(
        self,
        *,
        paper_group_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Records that the current user has viewed a brief for the given paper group

        Source file: `api-server/src/controllers/briefs/v1/mark-seen.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/briefs/v1/seen",
            body=await async_maybe_transform(
                {"paper_group_id": paper_group_id}, seen_mark_seen_params.SeenMarkSeenParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SeenResourceWithRawResponse:
    def __init__(self, seen: SeenResource) -> None:
        self._seen = seen

        self.get_seen = to_raw_response_wrapper(
            seen.get_seen,
        )
        self.mark_seen = to_raw_response_wrapper(
            seen.mark_seen,
        )


class AsyncSeenResourceWithRawResponse:
    def __init__(self, seen: AsyncSeenResource) -> None:
        self._seen = seen

        self.get_seen = async_to_raw_response_wrapper(
            seen.get_seen,
        )
        self.mark_seen = async_to_raw_response_wrapper(
            seen.mark_seen,
        )


class SeenResourceWithStreamingResponse:
    def __init__(self, seen: SeenResource) -> None:
        self._seen = seen

        self.get_seen = to_streamed_response_wrapper(
            seen.get_seen,
        )
        self.mark_seen = to_streamed_response_wrapper(
            seen.mark_seen,
        )


class AsyncSeenResourceWithStreamingResponse:
    def __init__(self, seen: AsyncSeenResource) -> None:
        self._seen = seen

        self.get_seen = async_to_streamed_response_wrapper(
            seen.get_seen,
        )
        self.mark_seen = async_to_streamed_response_wrapper(
            seen.mark_seen,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["PrivateCreateParams"]


class PrivateCreateParams(TypedDict, total=False):
    content_type: Required[Annotated[str, PropertyInfo(alias="contentType")]]

    file: Required[str]

    filename: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V3RequestImplementationResponse"]


class V3RequestImplementationResponse(BaseModel):
    requested: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["CitationGetSummaryResponse", "Citations", "HIndex", "I10Index"]


class Citations(BaseModel):
    all: float

    since_2020: float


class HIndex(BaseModel):
    all: float

    since_2020: float


class I10Index(BaseModel):
    all: float

    since_2020: float


class CitationGetSummaryResponse(BaseModel):
    citations: Citations

    h_index: HIndex

    i10_index: I10Index

    updated_at: str = FieldInfo(alias="updatedAt")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_send_message_params import V1SendMessageParams as V1SendMessageParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from .emails import (
    EmailsResource,
    AsyncEmailsResource,
    EmailsResourceWithRawResponse,
    AsyncEmailsResourceWithRawResponse,
    EmailsResourceWithStreamingResponse,
    AsyncEmailsResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....types.admin import v1_get_moderator_feed_params, v1_lookup_user_by_email_params
from ...._base_client import make_request_options
from ....types.admin.v1_get_moderator_feed_response import V1GetModeratorFeedResponse
from ....types.admin.v1_lookup_user_by_email_response import V1LookupUserByEmailResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def emails(self) -> EmailsResource:
        return EmailsResource(self._client)

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def get_moderator_feed(
        self,
        *,
        feed_type: Literal["all", "flagged", "recent"] | Omit = omit,
        page: str | Omit = omit,
        page_size: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetModeratorFeedResponse:
        """
        Get page of comments for moderator feed

        Source file:
        `api-server/src/controllers/admin/v1/get-moderator-feed.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/admin/v1/moderator-feed",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "feed_type": feed_type,
                        "page": page,
                        "page_size": page_size,
                    },
                    v1_get_moderator_feed_params.V1GetModeratorFeedParams,
                ),
            ),
            cast_to=V1GetModeratorFeedResponse,
        )

    def lookup_user_by_email(
        self,
        *,
        email: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1LookupUserByEmailResponse:
        """
        Look up a user by email address (admin only)

        Source file:
        `api-server/src/controllers/admin/v1/lookup-user-by-email.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/admin/v1/lookup-user-by-email",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"email": email}, v1_lookup_user_by_email_params.V1LookupUserByEmailParams),
            ),
            cast_to=V1LookupUserByEmailResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def emails(self) -> AsyncEmailsResource:
        return AsyncEmailsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def get_moderator_feed(
        self,
        *,
        feed_type: Literal["all", "flagged", "recent"] | Omit = omit,
        page: str | Omit = omit,
        page_size: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetModeratorFeedResponse:
        """
        Get page of comments for moderator feed

        Source file:
        `api-server/src/controllers/admin/v1/get-moderator-feed.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/admin/v1/moderator-feed",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "feed_type": feed_type,
                        "page": page,
                        "page_size": page_size,
                    },
                    v1_get_moderator_feed_params.V1GetModeratorFeedParams,
                ),
            ),
            cast_to=V1GetModeratorFeedResponse,
        )

    async def lookup_user_by_email(
        self,
        *,
        email: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1LookupUserByEmailResponse:
        """
        Look up a user by email address (admin only)

        Source file:
        `api-server/src/controllers/admin/v1/lookup-user-by-email.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/admin/v1/lookup-user-by-email",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"email": email}, v1_lookup_user_by_email_params.V1LookupUserByEmailParams
                ),
            ),
            cast_to=V1LookupUserByEmailResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_moderator_feed = to_raw_response_wrapper(
            v1.get_moderator_feed,
        )
        self.lookup_user_by_email = to_raw_response_wrapper(
            v1.lookup_user_by_email,
        )

    @cached_property
    def emails(self) -> EmailsResourceWithRawResponse:
        return EmailsResourceWithRawResponse(self._v1.emails)


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_moderator_feed = async_to_raw_response_wrapper(
            v1.get_moderator_feed,
        )
        self.lookup_user_by_email = async_to_raw_response_wrapper(
            v1.lookup_user_by_email,
        )

    @cached_property
    def emails(self) -> AsyncEmailsResourceWithRawResponse:
        return AsyncEmailsResourceWithRawResponse(self._v1.emails)


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_moderator_feed = to_streamed_response_wrapper(
            v1.get_moderator_feed,
        )
        self.lookup_user_by_email = to_streamed_response_wrapper(
            v1.lookup_user_by_email,
        )

    @cached_property
    def emails(self) -> EmailsResourceWithStreamingResponse:
        return EmailsResourceWithStreamingResponse(self._v1.emails)


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_moderator_feed = async_to_streamed_response_wrapper(
            v1.get_moderator_feed,
        )
        self.lookup_user_by_email = async_to_streamed_response_wrapper(
            v1.lookup_user_by_email,
        )

    @cached_property
    def emails(self) -> AsyncEmailsResourceWithStreamingResponse:
        return AsyncEmailsResourceWithStreamingResponse(self._v1.emails)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV2:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: AlphaxivCat) -> None:
        v2 = client.comments.v2.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: AlphaxivCat) -> None:
        with client.comments.v2.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_downvote(self, client: AlphaxivCat) -> None:
        v2 = client.comments.v2.downvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_downvote(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.with_raw_response.downvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_downvote(self, client: AlphaxivCat) -> None:
        with client.comments.v2.with_streaming_response.downvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_downvote(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.with_raw_response.downvote(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_flag(self, client: AlphaxivCat) -> None:
        v2 = client.comments.v2.flag(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            reason="reason",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_flag(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.with_raw_response.flag(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            reason="reason",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_flag(self, client: AlphaxivCat) -> None:
        with client.comments.v2.with_streaming_response.flag(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            reason="reason",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_flag(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.with_raw_response.flag(
                comment="",
                reason="reason",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle_endorse(self, client: AlphaxivCat) -> None:
        v2 = client.comments.v2.toggle_endorse(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_toggle_endorse(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.with_raw_response.toggle_endorse(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_toggle_endorse(self, client: AlphaxivCat) -> None:
        with client.comments.v2.with_streaming_response.toggle_endorse(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_toggle_endorse(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.with_raw_response.toggle_endorse(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_upvote(self, client: AlphaxivCat) -> None:
        v2 = client.comments.v2.upvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_upvote(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.with_raw_response.upvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_upvote(self, client: AlphaxivCat) -> None:
        with client.comments.v2.with_streaming_response.upvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_upvote(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.with_raw_response.upvote(
                "",
            )


class TestAsyncV2:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.comments.v2.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_downvote(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.comments.v2.downvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_downvote(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.with_raw_response.downvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_downvote(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.with_streaming_response.downvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_downvote(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.with_raw_response.downvote(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_flag(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.comments.v2.flag(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            reason="reason",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_flag(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.with_raw_response.flag(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            reason="reason",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_flag(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.with_streaming_response.flag(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            reason="reason",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_flag(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.with_raw_response.flag(
                comment="",
                reason="reason",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle_endorse(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.comments.v2.toggle_endorse(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_toggle_endorse(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.with_raw_response.toggle_endorse(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_toggle_endorse(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.with_streaming_response.toggle_endorse(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_toggle_endorse(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.with_raw_response.toggle_endorse(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_upvote(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.comments.v2.upvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_upvote(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.with_raw_response.upvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_upvote(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.with_streaming_response.upvote(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_upvote(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.with_raw_response.upvote(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.arxiv.v1.lab_retrieve_response import LabRetrieveResponse

__all__ = ["LabsResource", "AsyncLabsResource"]


class LabsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LabsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return LabsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LabsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return LabsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        unresolved: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabRetrieveResponse:
        """
        Gets data necessary to render arXiv labs.

        Source file:
        `api-server/src/controllers/arxiv/v1/get-arxiv-labs-data.controller.ts`

        Args:
          unresolved: An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not unresolved:
            raise ValueError(f"Expected a non-empty value for `unresolved` but received {unresolved!r}")
        return self._get(
            f"/arxiv/v1/{unresolved}/labs",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabRetrieveResponse,
        )


class AsyncLabsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLabsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLabsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLabsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncLabsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        unresolved: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabRetrieveResponse:
        """
        Gets data necessary to render arXiv labs.

        Source file:
        `api-server/src/controllers/arxiv/v1/get-arxiv-labs-data.controller.ts`

        Args:
          unresolved: An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not unresolved:
            raise ValueError(f"Expected a non-empty value for `unresolved` but received {unresolved!r}")
        return await self._get(
            f"/arxiv/v1/{unresolved}/labs",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LabRetrieveResponse,
        )


class LabsResourceWithRawResponse:
    def __init__(self, labs: LabsResource) -> None:
        self._labs = labs

        self.retrieve = to_raw_response_wrapper(
            labs.retrieve,
        )


class AsyncLabsResourceWithRawResponse:
    def __init__(self, labs: AsyncLabsResource) -> None:
        self._labs = labs

        self.retrieve = async_to_raw_response_wrapper(
            labs.retrieve,
        )


class LabsResourceWithStreamingResponse:
    def __init__(self, labs: LabsResource) -> None:
        self._labs = labs

        self.retrieve = to_streamed_response_wrapper(
            labs.retrieve,
        )


class AsyncLabsResourceWithStreamingResponse:
    def __init__(self, labs: AsyncLabsResource) -> None:
        self._labs = labs

        self.retrieve = async_to_streamed_response_wrapper(
            labs.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .analytics import (
    AnalyticsResource,
    AsyncAnalyticsResource,
    AnalyticsResourceWithRawResponse,
    AsyncAnalyticsResourceWithRawResponse,
    AnalyticsResourceWithStreamingResponse,
    AsyncAnalyticsResourceWithStreamingResponse,
)
from .paper_view_count import (
    PaperViewCountResource,
    AsyncPaperViewCountResource,
    PaperViewCountResourceWithRawResponse,
    AsyncPaperViewCountResourceWithRawResponse,
    PaperViewCountResourceWithStreamingResponse,
    AsyncPaperViewCountResourceWithStreamingResponse,
)

__all__ = [
    "PaperViewCountResource",
    "AsyncPaperViewCountResource",
    "PaperViewCountResourceWithRawResponse",
    "AsyncPaperViewCountResourceWithRawResponse",
    "PaperViewCountResourceWithStreamingResponse",
    "AsyncPaperViewCountResourceWithStreamingResponse",
    "AnalyticsResource",
    "AsyncAnalyticsResource",
    "AnalyticsResourceWithRawResponse",
    "AsyncAnalyticsResourceWithRawResponse",
    "AnalyticsResourceWithStreamingResponse",
    "AsyncAnalyticsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["LabRetrieveResponse"]


class LabRetrieveResponse(BaseModel):
    summary: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers import V2CommentResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV2:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_comment(self, client: AlphaxivCat) -> None:
        v2 = client.papers.v2.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
        )
        assert_matches_type(V2CommentResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_comment_with_all_params(self, client: AlphaxivCat) -> None:
        v2 = client.papers.v2.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
            highlight_color="#26fBC5dF",
        )
        assert_matches_type(V2CommentResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_comment(self, client: AlphaxivCat) -> None:
        response = client.papers.v2.with_raw_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert_matches_type(V2CommentResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_comment(self, client: AlphaxivCat) -> None:
        with client.papers.v2.with_streaming_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert_matches_type(V2CommentResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_comment(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version` but received ''"):
            client.papers.v2.with_raw_response.comment(
                version="",
                anchor_position={
                    "offset": 0,
                    "page_index": 0,
                    "span_index": 0,
                },
                body="body",
                focus_position={
                    "offset": 0,
                    "page_index": 0,
                    "span_index": 0,
                },
                highlight_rects=[
                    {
                        "page_index": 0,
                        "rects": [
                            {
                                "x1": 0,
                                "x2": 0,
                                "y1": 0,
                                "y2": 0,
                            }
                        ],
                    }
                ],
                parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                selected_text="selectedText",
                tag="anonymous",
                title="title",
            )


class TestAsyncV2:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_comment(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.papers.v2.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
        )
        assert_matches_type(V2CommentResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_comment_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.papers.v2.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
            highlight_color="#26fBC5dF",
        )
        assert_matches_type(V2CommentResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_comment(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v2.with_raw_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert_matches_type(V2CommentResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_comment(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v2.with_streaming_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            anchor_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            body="body",
            focus_position={
                "offset": 0,
                "page_index": 0,
                "span_index": 0,
            },
            highlight_rects=[
                {
                    "page_index": 0,
                    "rects": [
                        {
                            "x1": 0,
                            "x2": 0,
                            "y1": 0,
                            "y2": 0,
                        }
                    ],
                }
            ],
            parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selected_text="selectedText",
            tag="anonymous",
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert_matches_type(V2CommentResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_comment(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version` but received ''"):
            await async_client.papers.v2.with_raw_response.comment(
                version="",
                anchor_position={
                    "offset": 0,
                    "page_index": 0,
                    "span_index": 0,
                },
                body="body",
                focus_position={
                    "offset": 0,
                    "page_index": 0,
                    "span_index": 0,
                },
                highlight_rects=[
                    {
                        "page_index": 0,
                        "rects": [
                            {
                                "x1": 0,
                                "x2": 0,
                                "y1": 0,
                                "y2": 0,
                            }
                        ],
                    }
                ],
                parent_comment_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                selected_text="selectedText",
                tag="anonymous",
                title="title",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["PrivateUpdateMetadataParams", "Author"]


class PrivateUpdateMetadataParams(TypedDict, total=False):
    abstract: Required[str]

    authors: Required[Iterable[Author]]

    bibtex: Required[Optional[str]]

    categories: Required[SequenceNotStr[str]]

    publication_date: Required[Annotated[float, PropertyInfo(alias="publicationDate")]]

    title: Required[str]


class Author(TypedDict, total=False):
    name: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ImplementationCreateParams"]


class ImplementationCreateParams(TypedDict, total=False):
    implementation_type: Required[
        Annotated[Literal["alphaxiv", "marimo", "author"], PropertyInfo(alias="implementationType")]
    ]

    url: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PaperViewCountKickoffJobParams"]


class PaperViewCountKickoffJobParams(TypedDict, total=False):
    type: Required[str]
    """Time period filter: 'all' or number of days"""

    like: str
    """Optional filter for likes"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from ..._models import BaseModel

__all__ = ["V2ListTopResponse", "V2ListTopResponseItem"]


class V2ListTopResponseItem(BaseModel):
    id: str

    image: Optional[str] = None

    name: str

    slug: str


V2ListTopResponse: TypeAlias = List[V2ListTopResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .users import (
    UsersResource,
    AsyncUsersResource,
    UsersResourceWithRawResponse,
    AsyncUsersResourceWithRawResponse,
    UsersResourceWithStreamingResponse,
    AsyncUsersResourceWithStreamingResponse,
)
from .preferences import (
    PreferencesResource,
    AsyncPreferencesResource,
    PreferencesResourceWithRawResponse,
    AsyncPreferencesResourceWithRawResponse,
    PreferencesResourceWithStreamingResponse,
    AsyncPreferencesResourceWithStreamingResponse,
)

__all__ = [
    "V3Resource",
    "AsyncV3Resource",
    "V3ResourceWithRawResponse",
    "AsyncV3ResourceWithRawResponse",
    "V3ResourceWithStreamingResponse",
    "AsyncV3ResourceWithStreamingResponse",
    "PreferencesResource",
    "AsyncPreferencesResource",
    "PreferencesResourceWithRawResponse",
    "AsyncPreferencesResourceWithRawResponse",
    "PreferencesResourceWithStreamingResponse",
    "AsyncPreferencesResourceWithStreamingResponse",
    "UsersResource",
    "AsyncUsersResource",
    "UsersResourceWithRawResponse",
    "AsyncUsersResourceWithRawResponse",
    "UsersResourceWithStreamingResponse",
    "AsyncUsersResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_get_cumulative_users_response import V1GetCumulativeUsersResponse as V1GetCumulativeUsersResponse
from .v1_get_total_user_count_response import V1GetTotalUserCountResponse as V1GetTotalUserCountResponse
from .v1_get_total_paper_count_response import V1GetTotalPaperCountResponse as V1GetTotalPaperCountResponse
from .v1_get_daily_new_accounts_response import V1GetDailyNewAccountsResponse as V1GetDailyNewAccountsResponse
from .v1_get_daily_conversations_response import V1GetDailyConversationsResponse as V1GetDailyConversationsResponse
from .v1_get_total_comment_count_response import V1GetTotalCommentCountResponse as V1GetTotalCommentCountResponse
from .v1_get_weekly_private_notes_response import V1GetWeeklyPrivateNotesResponse as V1GetWeeklyPrivateNotesResponse
from .v1_get_weekly_public_comments_response import (
    V1GetWeeklyPublicCommentsResponse as V1GetWeeklyPublicCommentsResponse,
)
from .v1_get_daily_user_chat_messages_response import (
    V1GetDailyUserChatMessagesResponse as V1GetDailyUserChatMessagesResponse,
)
from .v1_get_total_private_notes_count_response import (
    V1GetTotalPrivateNotesCountResponse as V1GetTotalPrivateNotesCountResponse,
)
from .v1_get_weekly_message_counts_by_user_response import (
    V1GetWeeklyMessageCountsByUserResponse as V1GetWeeklyMessageCountsByUserResponse,
)
